/****************************************************************************
 *
 * $Id: vpServoException.h 4649 2014-02-07 14:57:11Z fspindle $
 *
 * This file is part of the ViSP software.
 * Copyright (C) 2005 - 2014 by INRIA. All rights reserved.
 * 
 * This software is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * ("GPL") version 2 as published by the Free Software Foundation.
 * See the file LICENSE.txt at the root directory of this source
 * distribution for additional information about the GNU GPL.
 *
 * For using ViSP with software that can not be combined with the GNU
 * GPL, please contact INRIA about acquiring a ViSP Professional 
 * Edition License.
 *
 * See http://www.irisa.fr/lagadic/visp/visp.html for more information.
 * 
 * This software was developed at:
 * INRIA Rennes - Bretagne Atlantique
 * Campus Universitaire de Beaulieu
 * 35042 Rennes Cedex
 * France
 * http://www.irisa.fr/lagadic
 *
 * If you have questions regarding the use of this file, please contact
 * INRIA at visp@inria.fr
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 *
 *
 * Description:
 * Exception that can be emited by the vpServo class and its derivates.
 *
 * Authors:
 * Eric Marchand
 *
 *****************************************************************************/

#ifndef __vpServoException_H
#define __vpServoException_H

/*!
  \file vpServoException.h
  \brief error that can be emited by the vpServo class and its derivates
*/

#include <visp/vpException.h>

#include <iostream>                /* Classe std::ostream.    */
#include <string>                  /* Classe string.     */

/* ------------------------------------------------------------------------- */
/* --- CLASS --------------------------------------------------------------- */
/* ------------------------------------------------------------------------- */

/*!
  \class vpServoException
  \ingroup Exception
  \brief Error that can be emited by the vpServo class and its derivates.
  \author Eric Marchand   (Eric.Marchand@irisa.fr) Irisa / Inria Rennes
 */
class VISP_EXPORT vpServoException : public vpException
{
  public:
    /*!

    \brief Lists the possible error than can be emmited while calling
    vpServo member
   */
    enum errorServoCodeEnum
    {
      //! Current or desired feature list is empty
      noFeatureError,
      //! No degree of freedom is available to achieve the secondary task.
      noDofFree,
      //! Task was not killed properly
      notKilledProperly,
      //! Other exception
      servoError
    } ;

  public:
    vpServoException (const int id,  const char* format, ...)
    {
      this->code = id;
      va_list args;
      va_start(args, format);
      setMessage(format, args);
      va_end (args);
    }
    vpServoException (const int id, const std::string & msg)
      : vpException(id, msg){ ; }
    vpServoException (const int id)
      : vpException(id){ ; }

};

#endif
